@@ -33,10 +33,6 @@
 #include <utility>
 #include <variant>
 
-#include "absl/base/thread_annotations.h"
-#include "absl/container/flat_hash_map.h"
-#include "absl/random/random.h"
-#include "absl/status/status.h"
 #include "src/core/call/metadata_batch.h"  // IWYU pragma: keep
 #include "src/core/ext/transport/chaotic_good/config.h"
 #include "src/core/ext/transport/chaotic_good/frame.h"
@@ -44,6 +40,7 @@
 #include "src/core/ext/transport/chaotic_good/frame_transport.h"
 #include "src/core/ext/transport/chaotic_good/message_reassembly.h"
 #include "src/core/ext/transport/chaotic_good/pending_connection.h"
+#include "src/core/ext/transport/chaotic_good/transport_context.h"
 #include "src/core/lib/promise/activity.h"
 #include "src/core/lib/promise/context.h"
 #include "src/core/lib/promise/for_each.h"
@@ -61,11 +58,16 @@
 #include "src/core/lib/transport/promise_endpoint.h"
 #include "src/core/lib/transport/transport.h"
 #include "src/core/util/sync.h"
+#include "absl/base/thread_annotations.h"
+#include "absl/container/flat_hash_map.h"
+#include "absl/random/random.h"
+#include "absl/status/status.h"
 
 namespace grpc_core {
 namespace chaotic_good {
 
-class ChaoticGoodClientTransport final : public ClientTransport {
+class ChaoticGoodClientTransport final : public ClientTransport,
+                                         public channelz::DataSource {
  public:
   ChaoticGoodClientTransport(const ChannelArgs& args,
                              OrphanablePtr<FrameTransport> frame_transport,
@@ -80,9 +82,20 @@ class ChaoticGoodClientTransport final : public ClientTransport {
   void SetPollsetSet(grpc_stream*, grpc_pollset_set*) override {}
   void PerformOp(grpc_transport_op*) override;
   void Orphan() override;
+  RefCountedPtr<channelz::SocketNode> GetSocketNode() const override {
+    return ctx_->socket_node;
+  }
+  void AddData(channelz::DataSink sink) override;
 
   void StartCall(CallHandler call_handler) override;
 
+  void StartWatch(RefCountedPtr<StateWatcher> watcher) override {
+    stream_dispatch_->StartWatch(std::move(watcher));
+  }
+  void StopWatch(RefCountedPtr<StateWatcher> watcher) override {
+    stream_dispatch_->StopWatch(std::move(watcher));
+  }
+
  private:
   struct Stream : public RefCounted<Stream> {
     explicit Stream(CallHandler call)
@@ -97,7 +110,9 @@ class ChaoticGoodClientTransport final : public ClientTransport {
 
   class StreamDispatch final : public FrameTransportSink {
    public:
-    explicit StreamDispatch(MpscSender<Frame> outgoing_frames);
+    StreamDispatch(MpscSender<OutgoingFrame> outgoing_frames,
+                   std::shared_ptr<grpc_event_engine::experimental::EventEngine>
+                       event_engine);
 
     void OnIncomingFrame(IncomingFrame incoming_frame) override;
     void OnFrameTransportClosed(absl::Status status) override;
@@ -109,6 +124,9 @@ class ChaoticGoodClientTransport final : public ClientTransport {
         OrphanablePtr<ConnectivityStateWatcherInterface> watcher);
     void StopConnectivityWatch(ConnectivityStateWatcherInterface* watcher);
 
+    void StartWatch(RefCountedPtr<StateWatcher> watcher);
+    void StopWatch(RefCountedPtr<StateWatcher> watcher);
+
    private:
     template <typename T>
     void DispatchFrame(IncomingFrame incoming_frame);
@@ -136,15 +154,17 @@ class ChaoticGoodClientTransport final : public ClientTransport {
     StreamMap stream_map_ ABSL_GUARDED_BY(mu_);
     ConnectivityStateTracker state_tracker_ ABSL_GUARDED_BY(mu_){
         "chaotic_good_client", GRPC_CHANNEL_READY};
-    MpscSender<Frame> outgoing_frames_;
+    RefCountedPtr<StateWatcher> watcher_ ABSL_GUARDED_BY(mu_);
+    MpscSender<OutgoingFrame> outgoing_frames_;
+    std::shared_ptr<grpc_event_engine::experimental::EventEngine> event_engine_;
   };
 
   auto CallOutboundLoop(uint32_t stream_id, CallHandler call_handler);
 
-  std::shared_ptr<grpc_event_engine::experimental::EventEngine> event_engine_;
+  const TransportContextPtr ctx_;
   grpc_event_engine::experimental::MemoryAllocator allocator_;
   RefCountedPtr<StreamDispatch> stream_dispatch_;
-  MpscSender<Frame> outgoing_frames_;
+  MpscSender<OutgoingFrame> outgoing_frames_;
   RefCountedPtr<Party> party_;
   MessageChunker message_chunker_;
   OrphanablePtr<FrameTransport> frame_transport_;
