@@ -16,6 +16,7 @@
 //
 //
 
+#include <grpc/event_engine/memory_allocator.h>
 #include <grpc/grpc.h>
 #include <grpc/impl/connectivity_state.h>
 #include <grpc/slice.h>
@@ -39,8 +40,9 @@
 #include <utility>
 #include <vector>
 
-#include "absl/log/check.h"
 #include "src/core/lib/iomgr/iomgr.h"
+#include "src/core/lib/surface/channel.h"
+#include "src/core/util/grpc_check.h"
 
 namespace grpc {
 
@@ -66,6 +68,11 @@ Channel::~Channel() {
   }
 }
 
+grpc_event_engine::experimental::MemoryAllocator* Channel::memory_allocator()
+    const {
+  return grpc_core::Channel::FromC(c_channel_)->memory_allocator();
+}
+
 namespace {
 
 inline grpc_slice SliceFromArray(const char* arr, size_t len) {
@@ -105,6 +112,12 @@ void ChannelResetConnectionBackoff(Channel* channel) {
   grpc_channel_reset_connect_backoff(channel->c_channel_);
 }
 
+int64_t ChannelGetChannelzUuid(Channel* channel) {
+  auto* node = grpc_channel_get_channelz_node(channel->c_channel_);
+  if (node == nullptr) return 0;
+  return node->uuid();
+}
+
 }  // namespace experimental
 
 grpc::internal::Call Channel::CreateCallInternal(
@@ -207,7 +220,7 @@ bool Channel::WaitForStateChangeImpl(grpc_connectivity_state last_observed,
   void* tag = nullptr;
   NotifyOnStateChangeImpl(last_observed, deadline, &cq, nullptr);
   cq.Next(&tag, &ok);
-  CHECK_EQ(tag, nullptr);
+  GRPC_CHECK_EQ(tag, nullptr);
   return ok;
 }
 
