@@ -31,10 +31,6 @@
 #include <string>
 #include <utility>
 
-#include "absl/container/flat_hash_map.h"
-#include "absl/container/flat_hash_set.h"
-#include "absl/functional/any_invocable.h"
-#include "absl/strings/string_view.h"
 #include "opentelemetry/metrics/async_instruments.h"
 #include "opentelemetry/metrics/meter_provider.h"
 #include "opentelemetry/metrics/observer_result.h"
@@ -43,12 +39,19 @@
 #include "opentelemetry/trace/tracer.h"
 #include "src/core/call/metadata_batch.h"
 #include "src/core/lib/channel/channel_args.h"
+#include "src/core/telemetry/instrument.h"
 #include "src/core/telemetry/metrics.h"
 #include "src/core/util/down_cast.h"
+#include "absl/container/flat_hash_map.h"
+#include "absl/container/flat_hash_set.h"
+#include "absl/functional/any_invocable.h"
+#include "absl/strings/string_view.h"
 
 namespace grpc {
 namespace internal {
 
+bool IsOpenTelemetryLabelOptional(absl::string_view label_key);
+
 // An iterable container interface that can be used as a return type for the
 // OpenTelemetry plugin's label injector.
 class LabelsIterable {
@@ -240,11 +243,21 @@ class OpenTelemetryPluginImpl
           channel_scope_filter);
   ~OpenTelemetryPluginImpl() override;
 
+  grpc_core::RefCountedPtr<grpc_core::CollectionScope> GetCollectionScope()
+      const override {
+    return collection_scope_;
+  }
+
  private:
-  class ClientCallTracer;
+  class ClientCallTracerInterface;
   class KeyValueIterable;
   class NPCMetricsKeyValueIterable;
-  class ServerCallTracer;
+  class ServerCallTracerInterface;
+  class ExporterCallback;
+  template <class Exporter>
+  class ExporterCallbackImpl;
+  class CounterExporter;
+  class ExportedMetricKeyValueIterable;
 
   // Creates a convenience wrapper to help iterate over only those plugin
   // options that are active over a given channel/server.
@@ -356,6 +369,12 @@ class OpenTelemetryPluginImpl
   };
 
   struct ClientMetrics {
+    struct Call {
+      std::unique_ptr<opentelemetry::metrics::Histogram<uint64_t>> retries;
+      std::unique_ptr<opentelemetry::metrics::Histogram<uint64_t>>
+          transparent_retries;
+      std::unique_ptr<opentelemetry::metrics::Histogram<double>> retry_delay;
+    } call;
     struct Attempt {
       std::unique_ptr<opentelemetry::metrics::Counter<uint64_t>> started;
       std::unique_ptr<opentelemetry::metrics::Histogram<double>> duration;
@@ -416,12 +435,13 @@ class OpenTelemetryPluginImpl
 
   // Returns the string form of \a key
   static absl::string_view OptionalLabelKeyToString(
-      grpc_core::ClientCallTracer::CallAttemptTracer::OptionalLabelKey key);
+      grpc_core::ClientCallTracerInterface::CallAttemptTracer::OptionalLabelKey
+          key);
 
   // Returns the OptionalLabelKey form of \a key if \a key is recognized and
   // is public, std::nullopt otherwise.
   static std::optional<
-      grpc_core::ClientCallTracer::CallAttemptTracer::OptionalLabelKey>
+      grpc_core::ClientCallTracerInterface::CallAttemptTracer::OptionalLabelKey>
   OptionalLabelStringToKey(absl::string_view key);
 
   static absl::string_view GetMethodFromPath(const grpc_core::Slice& path);
@@ -460,17 +480,20 @@ class OpenTelemetryPluginImpl
       ABSL_LOCKS_EXCLUDED(mu_) override;
   void RemoveCallback(grpc_core::RegisteredMetricCallback* callback)
       ABSL_LOCKS_EXCLUDED(mu_) override;
-  grpc_core::ClientCallTracer* GetClientCallTracer(
+  grpc_core::ClientCallTracerInterface* GetClientCallTracer(
       const grpc_core::Slice& path, bool registered_method,
       std::shared_ptr<grpc_core::StatsPlugin::ScopeConfig> scope_config)
       override;
-  grpc_core::ServerCallTracer* GetServerCallTracer(
+  grpc_core::ServerCallTracerInterface* GetServerCallTracer(
       std::shared_ptr<grpc_core::StatsPlugin::ScopeConfig> scope_config)
       override;
   bool IsInstrumentEnabled(
       grpc_core::GlobalInstrumentsRegistry::GlobalInstrumentHandle handle)
       const override;
 
+  void QueryMetrics(absl::Span<const absl::string_view> metrics,
+                    grpc_core::MetricsSink& sink);
+
   const absl::AnyInvocable<bool(const grpc_core::ChannelArgs& /*args*/) const>&
   server_selector() const {
     return server_selector_;
@@ -558,6 +581,9 @@ class OpenTelemetryPluginImpl
   absl::AnyInvocable<bool(
       const OpenTelemetryPluginBuilder::ChannelScope& /*scope*/) const>
       channel_scope_filter_;
+  std::vector<std::string> collapse_labels_;  // const after init
+  std::vector<std::unique_ptr<ExporterCallback>> exporter_callbacks_;
+  grpc_core::RefCountedPtr<grpc_core::CollectionScope> collection_scope_;
 };
 
 class GrpcTextMapCarrier
