@@ -18,9 +18,9 @@
 #include <grpc/slice.h>
 
 #include <cstdint>
+#include <utility>
+#include <vector>
 
-#include "absl/strings/string_view.h"
-#include "absl/types/span.h"
 #include "src/core/ext/transport/chttp2/transport/frame.h"
 #include "src/core/ext/transport/chttp2/transport/http2_settings.h"
 #include "src/core/ext/transport/chttp2/transport/http2_settings_manager.h"
@@ -28,6 +28,8 @@
 #include "src/core/lib/event_engine/default_event_engine.h"
 #include "src/core/lib/slice/slice.h"
 #include "src/core/lib/slice/slice_buffer.h"
+#include "absl/strings/string_view.h"
+#include "absl/types/span.h"
 
 namespace grpc_core {
 namespace transport {
@@ -73,18 +75,21 @@ class Http2FrameTestHelper {
         Http2RstStreamFrame{stream_id, error_code});
   }
 
-  EventEngineSlice EventEngineSliceFromHttp2SettingsFrameAck(
-      std::vector<Http2SettingsFrame::Setting> settings) const {
+  EventEngineSlice EventEngineSliceFromHttp2SettingsFrameAck() const {
     return EventEngineSliceFromHttp2Frame(Http2SettingsFrame{true, {}});
   }
 
+  EventEngineSlice EventEngineSliceFromHttp2SettingsFrame(
+      std::vector<Http2SettingsFrame::Setting> settings) const {
+    return EventEngineSliceFromHttp2Frame(
+        Http2SettingsFrame{false, std::move(settings)});
+  }
+
   EventEngineSlice EventEngineSliceFromHttp2SettingsFrameDefault() const {
     std::vector<Http2SettingsFrame::Setting> settings;
     settings.push_back({Http2Settings::kEnablePushWireId, 0});
     settings.push_back({Http2Settings::kMaxConcurrentStreamsWireId, 0u});
-    // TODO(tjagtap) : [PH2][P2] Replace with 65535 once flow control is
-    // done.
-    settings.push_back({Http2Settings::kInitialWindowSizeWireId, 2147483646u});
+    settings.push_back({Http2Settings::kInitialWindowSizeWireId, 65535u});
     settings.push_back({Http2Settings::kMaxHeaderListSizeWireId, 16384u});
     settings.push_back({Http2Settings::kGrpcAllowTrueBinaryMetadataWireId, 1u});
     return EventEngineSliceFromHttp2Frame(
