@@ -30,6 +30,10 @@ TRANSPORT_FIXTURE(ChaoticGoodSingleConnection) {
                   grpc_event_engine::experimental::EventEngine>(event_engine));
   chaotic_good::Config client_config(channel_args);
   chaotic_good::Config server_config(channel_args);
+  auto client_socket_node = chaotic_good::TcpFrameTransport::MakeSocketNode(
+      channel_args, control_endpoints.client);
+  auto server_socket_node = chaotic_good::TcpFrameTransport::MakeSocketNode(
+      channel_args, control_endpoints.server);
   auto client_transport =
       MakeOrphanable<chaotic_good::ChaoticGoodClientTransport>(
           channel_args,
@@ -37,8 +41,8 @@ TRANSPORT_FIXTURE(ChaoticGoodSingleConnection) {
               client_config.MakeTcpFrameTransportOptions(),
               std::move(control_endpoints.client),
               client_config.TakePendingDataEndpoints(),
-              channel_args.GetObjectRef<
-                  grpc_event_engine::experimental::EventEngine>()),
+              MakeRefCounted<chaotic_good::TransportContext>(
+                  channel_args, std::move(client_socket_node))),
           client_config.MakeMessageChunker());
   auto server_transport =
       MakeOrphanable<chaotic_good::ChaoticGoodServerTransport>(
@@ -47,8 +51,8 @@ TRANSPORT_FIXTURE(ChaoticGoodSingleConnection) {
               server_config.MakeTcpFrameTransportOptions(),
               std::move(control_endpoints.server),
               server_config.TakePendingDataEndpoints(),
-              channel_args.GetObjectRef<
-                  grpc_event_engine::experimental::EventEngine>()),
+              MakeRefCounted<chaotic_good::TransportContext>(
+                  channel_args, std::move(server_socket_node))),
           server_config.MakeMessageChunker());
   return ClientAndServerTransportPair{std::move(client_transport),
                                       std::move(server_transport)};
