@@ -23,10 +23,10 @@
 #include <string>
 #include <unordered_set>
 
-#include "absl/log/check.h"
-#include "gtest/gtest.h"
 #include "src/core/util/crash.h"
+#include "src/core/util/grpc_check.h"
 #include "test/core/test_util/test_config.h"
+#include "gtest/gtest.h"
 
 namespace grpc_core {
 
@@ -48,7 +48,7 @@ class SessionTracker {
   tsi::SslSessionPtr NewSession(long id) {
     static int ex_data_id = SSL_SESSION_get_ex_new_index(
         0, nullptr, nullptr, nullptr, DestroyExData);
-    CHECK_NE(ex_data_id, -1);
+    GRPC_CHECK_NE(ex_data_id, -1);
     // OpenSSL and different version of BoringSSL don't agree on API
     // so try both.
     tsi::SslSessionPtr session = NewSessionInternal(SSL_SESSION_new);
