@@ -27,12 +27,6 @@
 #include <string>
 #include <utility>
 
-#include "absl/status/status.h"
-#include "absl/status/statusor.h"
-#include "absl/strings/str_format.h"
-#include "absl/strings/string_view.h"
-#include "gmock/gmock.h"
-#include "gtest/gtest.h"
 #include "src/core/config/core_configuration.h"
 #include "src/core/credentials/transport/channel_creds_registry.h"
 #include "src/core/credentials/transport/tls/certificate_provider_factory.h"
@@ -47,14 +41,22 @@
 #include "src/core/xds/grpc/certificate_provider_store.h"
 #include "src/core/xds/grpc/xds_bootstrap_grpc.h"
 #include "src/core/xds/grpc/xds_server_grpc.h"
+#include "test/core/test_util/scoped_env_var.h"
 #include "test/core/test_util/test_config.h"
+#include "gmock/gmock.h"
+#include "gtest/gtest.h"
+#include "absl/status/status.h"
+#include "absl/status/statusor.h"
+#include "absl/strings/str_format.h"
+#include "absl/strings/string_view.h"
 
 namespace grpc_core {
 namespace testing {
 namespace {
 
-MATCHER_P5(EqXdsServer, name, creds_config_type, ignore_resource_deletion,
-           fail_on_data_errors, trusted_xds_server, "equals XdsServer") {
+MATCHER_P6(EqXdsServer, name, channel_creds_config_type, call_creds_matcher,
+           ignore_resource_deletion, fail_on_data_errors, trusted_xds_server,
+           "equals XdsServer") {
   auto* server = static_cast<const GrpcXdsServer*>(arg);
   if (!::testing::ExplainMatchResult(::testing::Ne(nullptr), server,
                                      result_listener)) {
@@ -70,13 +72,21 @@ MATCHER_P5(EqXdsServer, name, creds_config_type, ignore_resource_deletion,
   ok &= ::testing::ExplainMatchResult(server->TrustedXdsServer(),
                                       trusted_xds_server, result_listener);
   auto& server_target = DownCast<const GrpcXdsServerTarget&>(*server->target());
-  auto creds_config = server_target.channel_creds_config();
-  if (!::testing::ExplainMatchResult(::testing::Ne(nullptr), creds_config,
-                                     result_listener)) {
+  auto channel_creds_config = server_target.channel_creds_config();
+  if (!::testing::ExplainMatchResult(::testing::Ne(nullptr),
+                                     channel_creds_config, result_listener)) {
     return false;
   }
-  ok &= ::testing::ExplainMatchResult(creds_config_type, creds_config->type(),
-                                      result_listener);
+  ok &= ::testing::ExplainMatchResult(
+      channel_creds_config_type, channel_creds_config->type(), result_listener);
+  ok &= ::testing::ExplainMatchResult(
+      call_creds_matcher, server_target.call_creds_configs(), result_listener);
+  return ok;
+}
+
+MATCHER_P2(EqCredsConfig, type, config, "equals creds config") {
+  bool ok = ::testing::ExplainMatchResult(type, arg->type(), result_listener);
+  ok &= ::testing::ExplainMatchResult(config, arg->ToString(), result_listener);
   return ok;
 }
 
@@ -156,9 +166,10 @@ TEST(XdsBootstrapTest, Basic) {
   auto bootstrap_or = GrpcXdsBootstrap::Create(json_str);
   ASSERT_TRUE(bootstrap_or.ok()) << bootstrap_or.status();
   auto bootstrap = std::move(*bootstrap_or);
-  EXPECT_THAT(bootstrap->servers(),
-              ::testing::ElementsAre(
-                  EqXdsServer("fake:///lb1", "fake", false, false, false)));
+  EXPECT_THAT(
+      bootstrap->servers(),
+      ::testing::ElementsAre(EqXdsServer(
+          "fake:///lb1", "fake", ::testing::IsEmpty(), false, false, false)));
   EXPECT_EQ(bootstrap->authorities().size(), 2);
   auto* authority = static_cast<const GrpcXdsBootstrap::GrpcAuthority*>(
       bootstrap->LookupAuthority("xds.example.com"));
@@ -168,7 +179,8 @@ TEST(XdsBootstrapTest, Basic) {
             "server/%s");
   EXPECT_THAT(authority->servers(),
               ::testing::ElementsAre(EqXdsServer("fake:///xds_server", "fake",
-                                                 true, false, false)));
+                                                 ::testing::IsEmpty(), true,
+                                                 false, false)));
   authority = static_cast<const GrpcXdsBootstrap::GrpcAuthority*>(
       bootstrap->LookupAuthority("xds.example2.com"));
   ASSERT_NE(authority, nullptr);
@@ -177,7 +189,8 @@ TEST(XdsBootstrapTest, Basic) {
             "server/%s");
   EXPECT_THAT(authority->servers(),
               ::testing::ElementsAre(EqXdsServer("fake:///xds_server3", "fake",
-                                                 false, true, true)));
+                                                 ::testing::IsEmpty(), false,
+                                                 true, true)));
   ASSERT_NE(bootstrap->node(), nullptr);
   EXPECT_EQ(bootstrap->node()->id(), "foo");
   EXPECT_EQ(bootstrap->node()->cluster(), "bar");
@@ -213,9 +226,10 @@ TEST(XdsBootstrapTest, ValidWithoutNode) {
   auto bootstrap_or = GrpcXdsBootstrap::Create(json_str);
   ASSERT_TRUE(bootstrap_or.ok()) << bootstrap_or.status();
   auto bootstrap = std::move(*bootstrap_or);
-  EXPECT_THAT(bootstrap->servers(),
-              ::testing::ElementsAre(
-                  EqXdsServer("fake:///lb", "fake", false, false, false)));
+  EXPECT_THAT(
+      bootstrap->servers(),
+      ::testing::ElementsAre(EqXdsServer(
+          "fake:///lb", "fake", ::testing::IsEmpty(), false, false, false)));
   EXPECT_EQ(bootstrap->node(), nullptr);
 }
 
@@ -233,8 +247,9 @@ TEST(XdsBootstrapTest, InsecureCreds) {
   ASSERT_TRUE(bootstrap_or.ok()) << bootstrap_or.status();
   auto bootstrap = std::move(*bootstrap_or);
   EXPECT_THAT(bootstrap->servers(),
-              ::testing::ElementsAre(
-                  EqXdsServer("fake:///lb", "insecure", false, false, false)));
+              ::testing::ElementsAre(EqXdsServer("fake:///lb", "insecure",
+                                                 ::testing::IsEmpty(), false,
+                                                 false, false)));
   EXPECT_EQ(bootstrap->node(), nullptr);
 }
 
@@ -269,7 +284,8 @@ TEST(XdsBootstrapTest, GoogleDefaultCreds) {
   auto bootstrap = std::move(*bootstrap_or);
   EXPECT_THAT(bootstrap->servers(),
               ::testing::ElementsAre(EqXdsServer("fake:///lb", "google_default",
-                                                 false, false, false)));
+                                                 ::testing::IsEmpty(), false,
+                                                 false, false)));
   EXPECT_EQ(bootstrap->node(), nullptr);
 }
 
@@ -307,7 +323,7 @@ TEST(XdsBootstrapTest, NoKnownChannelCreds) {
       << bootstrap.status();
 }
 
-TEST(XdsBootstrapTest, MultipleCreds) {
+TEST(XdsBootstrapTest, MultipleChannelCreds) {
   const char* json_str =
       "{"
       "  \"xds_servers\": ["
@@ -320,12 +336,96 @@ TEST(XdsBootstrapTest, MultipleCreds) {
       "}";
   auto bootstrap = GrpcXdsBootstrap::Create(json_str);
   ASSERT_TRUE(bootstrap.ok()) << bootstrap.status();
-  EXPECT_THAT((*bootstrap)->servers(),
-              ::testing::ElementsAre(
-                  EqXdsServer("fake:///lb", "fake", false, false, false)));
+  EXPECT_THAT(
+      (*bootstrap)->servers(),
+      ::testing::ElementsAre(EqXdsServer(
+          "fake:///lb", "fake", ::testing::IsEmpty(), false, false, false)));
   EXPECT_EQ((*bootstrap)->node(), nullptr);
 }
 
+TEST(XdsBootstrapTest, WithCallCreds) {
+  ScopedExperimentalEnvVar env("GRPC_EXPERIMENTAL_XDS_BOOTSTRAP_CALL_CREDS");
+  const char* json_str =
+      "{"
+      "  \"xds_servers\": ["
+      "    {"
+      "      \"server_uri\": \"fake:///lb\","
+      "      \"channel_creds\": [{\"type\": \"insecure\"}],"
+      "      \"call_creds\": ["
+      "         {\"type\": \"unknown\"},"  // Ignored.
+      "         {\"type\": \"jwt_token_file\","
+      "          \"config\": {\"jwt_token_file\": \"/path/to/file\"}},"
+      "         {\"type\": \"jwt_token_file\","
+      "          \"config\": {\"jwt_token_file\": \"/some/other/path\"}}"
+      "      ]"
+      "    }"
+      "  ]"
+      "}";
+  auto bootstrap_or = GrpcXdsBootstrap::Create(json_str);
+  ASSERT_TRUE(bootstrap_or.ok()) << bootstrap_or.status();
+  auto bootstrap = std::move(*bootstrap_or);
+  EXPECT_THAT(
+      bootstrap->servers(),
+      ::testing::ElementsAre(EqXdsServer(
+          "fake:///lb", "insecure",
+          ::testing::ElementsAre(
+              EqCredsConfig("jwt_token_file", "{path=\"/path/to/file\"}"),
+              EqCredsConfig("jwt_token_file", "{path=\"/some/other/path\"}")),
+          false, false, false)));
+  EXPECT_EQ(bootstrap->node(), nullptr);
+}
+
+TEST(XdsBootstrapTest, InvalidCallCredsConfig) {
+  ScopedExperimentalEnvVar env("GRPC_EXPERIMENTAL_XDS_BOOTSTRAP_CALL_CREDS");
+  const char* json_str =
+      "{"
+      "  \"xds_servers\": ["
+      "    {"
+      "      \"server_uri\": \"fake:///lb\","
+      "      \"channel_creds\": [{\"type\": \"insecure\"}],"
+      "      \"call_creds\": ["
+      "         {\"type\": \"unknown\"},"  // Ignored.
+      "         {\"type\": \"jwt_token_file\", \"config\": {}}"
+      "      ]"
+      "    }"
+      "  ]"
+      "}";
+  auto bootstrap = GrpcXdsBootstrap::Create(json_str);
+  EXPECT_EQ(bootstrap.status().message(),
+            "errors validating JSON: ["
+            "field:xds_servers[0].call_creds[1].config.jwt_token_file "
+            "error:field not present]")
+      << bootstrap.status();
+}
+
+// TODO(roth): Remove this when env var guard goes away.
+TEST(XdsBootstrapTest, CallCredsIgnoredWithoutEnvVar) {
+  const char* json_str =
+      "{"
+      "  \"xds_servers\": ["
+      "    {"
+      "      \"server_uri\": \"fake:///lb\","
+      "      \"channel_creds\": [{\"type\": \"insecure\"}],"
+      "      \"call_creds\": ["
+      "         {\"type\": \"unknown\"},"
+      "         {\"type\": \"jwt_token_file\","
+      "          \"config\": {\"jwt_token_file\": \"/path/to/file\"}},"
+      "         {\"type\": \"jwt_token_file\","
+      "          \"config\": {\"jwt_token_file\": \"/some/other/path\"}}"
+      "      ]"
+      "    }"
+      "  ]"
+      "}";
+  auto bootstrap_or = GrpcXdsBootstrap::Create(json_str);
+  ASSERT_TRUE(bootstrap_or.ok()) << bootstrap_or.status();
+  auto bootstrap = std::move(*bootstrap_or);
+  EXPECT_THAT(bootstrap->servers(),
+              ::testing::ElementsAre(EqXdsServer("fake:///lb", "insecure",
+                                                 ::testing::IsEmpty(), false,
+                                                 false, false)));
+  EXPECT_EQ(bootstrap->node(), nullptr);
+}
+
 TEST(XdsBootstrapTest, MissingXdsServers) {
   auto bootstrap = GrpcXdsBootstrap::Create("{}");
   EXPECT_EQ(
@@ -794,16 +894,19 @@ TEST(XdsBootstrapTest, MultipleXdsServers) {
   auto bootstrap = std::move(*bootstrap_or);
   EXPECT_THAT(bootstrap->servers(),
               ::testing::ElementsAre(
-                  EqXdsServer("fake:///lb1", "fake", false, false, false),
-                  EqXdsServer("fake:///lb2", "fake", false, false, false)));
+                  EqXdsServer("fake:///lb1", "fake", ::testing::IsEmpty(),
+                              false, false, false),
+                  EqXdsServer("fake:///lb2", "fake", ::testing::IsEmpty(),
+                              false, false, false)));
   auto* authority = static_cast<const GrpcXdsBootstrap::GrpcAuthority*>(
       bootstrap->LookupAuthority("xds.example.com"));
   ASSERT_NE(authority, nullptr);
-  EXPECT_THAT(
-      authority->servers(),
-      ::testing::ElementsAre(
-          EqXdsServer("fake:///xds_server", "fake", false, false, false),
-          EqXdsServer("fake:///xds_server2", "fake", false, false, false)));
+  EXPECT_THAT(authority->servers(),
+              ::testing::ElementsAre(
+                  EqXdsServer("fake:///xds_server", "fake",
+                              ::testing::IsEmpty(), false, false, false),
+                  EqXdsServer("fake:///xds_server2", "fake",
+                              ::testing::IsEmpty(), false, false, false)));
 }
 
 }  // namespace
