@@ -30,17 +30,17 @@
 #include <memory>
 #include <thread>
 
-#include "absl/log/check.h"
-#include "gtest/gtest.h"
 #include "src/core/lib/iomgr/port.h"
 #include "src/core/util/crash.h"
 #include "src/core/util/env.h"
+#include "src/core/util/grpc_check.h"
 #include "src/proto/grpc/testing/duplicate/echo_duplicate.grpc.pb.h"
 #include "src/proto/grpc/testing/echo.grpc.pb.h"
 #include "test/core/test_util/port.h"
 #include "test/core/test_util/test_config.h"
 #include "test/cpp/util/byte_buffer_proto_helper.h"
 #include "test/cpp/util/string_ref_helper.h"
+#include "gtest/gtest.h"
 
 using grpc::testing::EchoRequest;
 using grpc::testing::EchoResponse;
@@ -76,7 +76,7 @@ class Verifier {
   // Verify keeps calling Next until all currently set
   // expected tags are complete
   void Verify(CompletionQueue* cq) {
-    CHECK(!expectations_.empty());
+    GRPC_CHECK(!expectations_.empty());
     while (!expectations_.empty()) {
       Next(cq, false);
     }
